@@ -6,7 +6,7 @@
 #include "webgl1.h"
 #include "webgl2.h"
 
-#ifdef __EMSCRIPTEN_PTHREADS__
+#if defined(__EMSCRIPTEN_PTHREADS__) && defined(__EMSCRIPTEN_OFFSCREEN_FRAMEBUFFER__)
 
 ASYNC_GL_FUNCTION_1(EM_FUNC_SIG_VI, void, glReadBuffer, GLenum);
 ASYNC_GL_FUNCTION_6(EM_FUNC_SIG_VIIIIII, void, glDrawRangeElements, GLenum, GLuint, GLuint, GLsizei, GLenum, const void *); // TODO: Not async if rendering from client side memory
@@ -147,6 +147,31 @@ GL_APICALL GLboolean GL_APIENTRY glIsVertexArrayOES(GLuint array) { return glIsV
 GL_APICALL void GL_APIENTRY glDrawBuffersEXT(GLsizei n, const GLenum *bufs) { glDrawBuffers(n, bufs); }
 GL_APICALL void GL_APIENTRY glDrawBuffersWEBGL(GLsizei n, const GLenum *bufs) { glDrawBuffers(n, bufs); }
 
+// Returns a function pointer to the given WebGL 2 extension function, when queried without
+// a GL extension suffix such as "EXT", "OES", or "ANGLE". This function is used by
+// emscripten_GetProcAddress() to implement legacy GL emulation semantics for portability.
+void *_webgl2_match_ext_proc_address_without_suffix(const char *name)
+{
+	RETURN_FN_WITH_SUFFIX(glVertexAttribDivisor, EXT);
+	RETURN_FN_WITH_SUFFIX(glVertexAttribDivisor, ARB);
+	RETURN_FN_WITH_SUFFIX(glVertexAttribDivisor, ANGLE);
+	RETURN_FN_WITH_SUFFIX(glDrawArraysInstanced, EXT);
+	RETURN_FN_WITH_SUFFIX(glDrawArraysInstanced, ARB);
+	RETURN_FN_WITH_SUFFIX(glDrawArraysInstanced, ANGLE);
+	RETURN_FN_WITH_SUFFIX(glDrawElementsInstanced, NV);
+	RETURN_FN_WITH_SUFFIX(glDrawElementsInstanced, EXT);
+	RETURN_FN_WITH_SUFFIX(glDrawElementsInstanced, ARB);
+	RETURN_FN_WITH_SUFFIX(glDrawElementsInstanced, ANGLE);
+	RETURN_FN_WITH_SUFFIX(glBindVertexArray, OES);
+	RETURN_FN_WITH_SUFFIX(glDeleteVertexArrays, OES);
+	RETURN_FN_WITH_SUFFIX(glGenVertexArrays, OES);
+	RETURN_FN_WITH_SUFFIX(glIsVertexArray, OES);
+	RETURN_FN_WITH_SUFFIX(glDrawBuffers, EXT);
+	RETURN_FN_WITH_SUFFIX(glDrawBuffers, WEBGL);
+
+	return 0;
+}
+
 void *emscripten_webgl2_get_proc_address(const char *name)
 {
 	RETURN_FN(glReadBuffer);
